@@ -5,16 +5,17 @@
 # all_traits_features.py --- Shows primary features of the Traits
 #                            package
 
-#--[Imports]-------------------------------------------------------------------
+# --[Imports]-------------------------------------------------------------------
+from __future__ import print_function
 from traits.api import Delegate, HasTraits, Instance, Int, Str
 
 
-#--[Code]----------------------------------------------------------------------
+# --[Code]----------------------------------------------------------------------
 # Shows the five primary features of the Traits package.
 class Parent(HasTraits):
 
     # INITIALIZATION: last_name' is initialized to '':
-    last_name = Str('')
+    last_name = Str("")
 
 
 class Child(HasTraits):
@@ -25,22 +26,23 @@ class Child(HasTraits):
     father = Instance(Parent)
 
     # DELEGATION: 'last_name' is delegated to father's 'last_name':
-    last_name = Delegate('father')
+    last_name = Delegate("father")
 
     # NOTIFICATION: This method is called when 'age' changes:
     def _age_changed(self, old, new):
-        print 'Age changed from %s to %s ' % (old, new)
+        print("Age changed from %s to %s " % (old, new))
 
-#--[Example*]------------------------------------------------------------------
+
+# --[Example*]------------------------------------------------------------------
 
 # Set up the example:
 joe = Parent()
-joe.last_name = 'Johnson'
+joe.last_name = "Johnson"
 moe = Child()
 moe.father = joe
 
 # DELEGATION in action:
-print "Moe's last name is %s " % moe.last_name
+print("Moe's last name is %s " % moe.last_name)
 # Result:
 # Moe's last name is Johnson
 
