@@ -2,13 +2,15 @@
 #  License: BSD Style.
 
 
-#--[Imports]-------------------------------------------------------------------
+# --[Imports]-------------------------------------------------------------------
+from __future__ import print_function
 from traits.api import HasTraits, Instance
 
 
-#--[Code]----------------------------------------------------------------------
+# --[Code]----------------------------------------------------------------------
 # Shows the incorrect way of defining mutually-referring classes.
 try:
+
     class Chicken(HasTraits):
 
         # Won't work: 'Egg' not defined yet:
@@ -20,5 +22,6 @@ try:
         # 'Chicken' won't be defined yet:
         created_by = Instance(Chicken)
 
-except NameError, excp:
-    print excp
+
+except NameError as excp:
+    print(excp)
