@@ -3,17 +3,17 @@
 
 # event.py --- Example of a trait event
 
-#--<Imports>-------------------------------------------------------------------
+# --<Imports>-------------------------------------------------------------------
 from traits.api import Event, HasTraits, List, RGBColor, Tuple
 
-#--[Code]----------------------------------------------------------------------
+# --[Code]----------------------------------------------------------------------
 
 point_2d = Tuple(0, 0)
 
 
 class Line2D(HasTraits):
     points = List(point_2d)
-    line_color = RGBColor('black')
+    line_color = RGBColor("black")
     updated = Event
 
     def redraw(self):
