@@ -3,13 +3,13 @@
 
 # simple_adapter.py - Example of adaptation using Adapter
 
-#--[Imports]-------------------------------------------------------------------
+# --[Imports]-------------------------------------------------------------------
 from traits.api import Adapter, Instance, implements
 from interface_definition import IName
 from interface_implementation import Person
 
 
-#--[Code]----------------------------------------------------------------------
+# --[Code]----------------------------------------------------------------------
 class PersonINameAdapter(Adapter):
 
     # Declare what interfaces this adapter implements for its
@@ -21,5 +21,4 @@ class PersonINameAdapter(Adapter):
 
     # Implement the 'IName' interface on behalf of its client:
     def get_name(self):
-        return ('%s %s' % (self.adaptee.first_name,
-                           self.adaptee.last_name))
+        return "%s %s" % (self.adaptee.first_name, self.adaptee.last_name)
