@@ -3,13 +3,12 @@
 
 # use_custom_th.py --- Example of using a custom TraitHandler
 
-#--[Imports]-------------------------------------------------------------------
+# --[Imports]-------------------------------------------------------------------
 from traits.api import HasTraits, Trait, TraitRange
 from custom_traithandler import TraitOddInteger
 
 
-#--[Code]----------------------------------------------------------------------
+# --[Code]----------------------------------------------------------------------
 class AnOddClass(HasTraits):
     oddball = Trait(1, TraitOddInteger())
-    very_odd = Trait(-1, TraitOddInteger(),
-                     TraitRange(-10, -1))
+    very_odd = Trait(-1, TraitOddInteger(), TraitRange(-10, -1))
