@@ -1,7 +1,7 @@
 #  Copyright (c) 2007, Enthought, Inc.
 #  License: BSD Style.
 
-#--(on_trait_change Decorator)-------------------------------------------------
+# --(on_trait_change Decorator)-------------------------------------------------
 """
 on_trait_change Decorator
 =========================
@@ -115,12 +115,12 @@ Refer to the code tabs of this lesson for a complete example using the
 *sick_again* method in the **Corporation Class** tab.
 """
 
-#--<Imports>-------------------------------------------------------------------
-
+# --<Imports>-------------------------------------------------------------------
+from __future__ import print_function
 from traits.api import *
 
 
-#--[Employee Class]------------------------------------------------------------
+# --[Employee Class]------------------------------------------------------------
 class Employee(HasTraits):
 
     # The name of the employee:
@@ -130,7 +130,7 @@ class Employee(HasTraits):
     sick_days = Int
 
 
-#--[Department Class]----------------------------------------------------------
+# --[Department Class]----------------------------------------------------------
 class Department(HasTraits):
 
     # The name of the department:
@@ -140,7 +140,7 @@ class Department(HasTraits):
     employees = List(Employee)
 
 
-#--[Corporation Class]---------------------------------------------------------
+# --[Corporation Class]---------------------------------------------------------
 class Corporation(HasTraits):
 
     # The name of the corporation:
@@ -150,37 +150,37 @@ class Corporation(HasTraits):
     departments = List(Department)
 
     # Define a corporate 'whistle blower' method:
-    @on_trait_change('departments:employees.sick_days')
+    @on_trait_change("departments:employees.sick_days")
     def sick_again(self, object, name, old, new):
-        print '%s just took sick day number %d for this year!' % (
-              object.name, new)
+        print(
+            "%s just took sick day number %d for this year!"
+            % (object.name, new)
+        )
 
 
-#--[Example*]------------------------------------------------------------------
+# --[Example*]------------------------------------------------------------------
 # Create some sample employees:
-millie = Employee(name='Millie', sick_days=2)
-ralph = Employee(name='Ralph', sick_days=3)
-tom = Employee(name='Tom', sick_days=1)
-slick = Employee(name='Slick', sick_days=16)
-marcelle = Employee(name='Marcelle', sick_days=7)
-reggie = Employee(name='Reggie', sick_days=11)
-dave = Employee(name='Dave', sick_days=0)
-bob = Employee(name='Bob', sick_days=1)
-alphonse = Employee(name='Alphonse', sick_days=5)
+millie = Employee(name="Millie", sick_days=2)
+ralph = Employee(name="Ralph", sick_days=3)
+tom = Employee(name="Tom", sick_days=1)
+slick = Employee(name="Slick", sick_days=16)
+marcelle = Employee(name="Marcelle", sick_days=7)
+reggie = Employee(name="Reggie", sick_days=11)
+dave = Employee(name="Dave", sick_days=0)
+bob = Employee(name="Bob", sick_days=1)
+alphonse = Employee(name="Alphonse", sick_days=5)
 
 # Create some sample departments:
-accounting = Department(name='accounting',
-                        employees=[millie, ralph, tom])
+accounting = Department(name="accounting", employees=[millie, ralph, tom])
 
-sales = Department(name='Sales',
-                   employees=[slick, marcelle, reggie])
+sales = Department(name="Sales", employees=[slick, marcelle, reggie])
 
-development = Department(name='Development',
-                         employees=[dave, bob, alphonse])
+development = Department(name="Development", employees=[dave, bob, alphonse])
 
 # Create a sample corporation:
-acme = Corporation(name='Acme, Inc.',
-                   departments=[accounting, sales, development])
+acme = Corporation(
+    name="Acme, Inc.", departments=[accounting, sales, development]
+)
 
 # Now let's try out our 'reporting' system:
 slick.sick_days += 1
