@@ -1,7 +1,7 @@
 #  Copyright (c) 2007, Enthought, Inc.
 #  License: BSD Style.
 
-#--(Extended Property depends_on References)-----------------------------------
+# --(Extended Property depends_on References)-----------------------------------
 """
 Extended Property *depends_on* References
 =========================================
@@ -53,8 +53,12 @@ trait reference. In particular, take a look at the **LeagueModelView Class**
 tab's *total_hits* trait definition.
 """
 
+from __future__ import print_function
+
 # FIXME redo example without traitsui
 
+import six.moves as sm
+
 from traits.api import *
 
 from traitsui.api import *
@@ -62,29 +66,29 @@ from traitsui.api import *
 from traitsui.table_column import *
 
 
-#--[Player Class]--------------------------------------------------------------
+# --[Player Class]--------------------------------------------------------------
 # Define a baseball player:
 class Player(HasTraits):
 
     # The name of the player:
-    name = Str('<new player>')
+    name = Str("<new player>")
 
     # The number of hits the player made this season:
     hits = Int
 
 
-#--[Team Class]----------------------------------------------------------------
+# --[Team Class]----------------------------------------------------------------
 # Define a baseball team:
 class Team(HasTraits):
 
     # The name of the team:
-    name = Str('<new team>')
+    name = Str("<new team>")
 
     # The players on the team:
     players = List(Player)
 
     # The number of players on the team:
-    num_players = Property(depends_on='players')
+    num_players = Property(depends_on="players")
 
     def _get_num_players(self):
         """ Implementation of the 'num_players' property.
@@ -92,18 +96,18 @@ class Team(HasTraits):
         return len(self.players)
 
 
-#--[League Class]--------------------------------------------------------------
+# --[League Class]--------------------------------------------------------------
 # Define a baseball league model:
 class League(HasTraits):
 
     # The name of the league:
-    name = Str('<new league>')
+    name = Str("<new league>")
 
     # The teams in the league:
     teams = List(Team)
 
 
-#--[LeagueModelView Class]-----------------------------------------------------
+# --[LeagueModelView Class]-----------------------------------------------------
 # Define a ModelView for a League model:
 class LeagueModelView(ModelView):
 
@@ -114,74 +118,89 @@ class LeagueModelView(ModelView):
     player = Instance(Player)
 
     # Button to add a hit to the current player:
-    got_hit = Button('Got a Hit')
+    got_hit = Button("Got a Hit")
 
     # The total number of hits (note the 'depends_on' extended trait
     # reference):
-    total_hits = Property(depends_on='model.teams.players.hits')
+    total_hits = Property(depends_on="model.teams.players.hits")
 
     @cached_property
     def _get_total_hits(self):
         """ Returns the total number of hits across all teams and players.
         """
-        return reduce(add, [reduce(add, [p.hits for p in t.players], 0)
-                            for t in self.model.teams], 0)
+        return sm.reduce(
+            add,
+            [
+                sm.reduce(add, [p.hits for p in t.players], 0)
+                for t in self.model.teams
+            ],
+            0,
+        )
 
     view = View(
         VGroup(
             HGroup(
-                Item('total_hits', style='readonly'),
-                label='League Statistics',
+                Item("total_hits", style="readonly"),
+                label="League Statistics",
                 show_border=True,
-                ),
+            ),
             VGroup(
-                Item('model.teams',
-                     show_label=False,
-                     editor=TableEditor(
-                         columns=[ObjectColumn(name='name',
-                                               width=0.70),
-                                  ObjectColumn(name='num_players',
-                                               label='# Players',
-                                               editable=False,
-                                               width=0.29)],
-                         selected='object.team',
-                         auto_add=True,
-                         row_factory=Team,
-                         configurable=False,
-                         sortable=False)
-                     ),
-                label='League Teams',
-                show_border=True,
-                ),
-            VGroup(
-                Item('object.team.players',
-                     show_label=False,
-                     editor=TableEditor(
-                         columns=[ObjectColumn(name='name',
-                                               width=0.70),
-                                  ObjectColumn(name='hits',
-                                               editable=False,
-                                               width=0.29)],
-                         selected='object.player',
-                         auto_add=True,
-                         row_factory=Player,
-                         configurable=False,
-                         sortable=False),
-                     ),
-                '_',
-                HGroup(
-                    Item('got_hit',
-                         show_label=False,
-                         enabled_when='player is not None',
-                         ),
+                Item(
+                    "model.teams",
+                    show_label=False,
+                    editor=TableEditor(
+                        columns=[
+                            ObjectColumn(name="name", width=0.70),
+                            ObjectColumn(
+                                name="num_players",
+                                label="# Players",
+                                editable=False,
+                                width=0.29,
+                            ),
+                        ],
+                        selected="object.team",
+                        auto_add=True,
+                        row_factory=Team,
+                        configurable=False,
+                        sortable=False,
                     ),
-                label='Team Players',
+                ),
+                label="League Teams",
+                show_border=True,
+            ),
+            VGroup(
+                Item(
+                    "object.team.players",
+                    show_label=False,
+                    editor=TableEditor(
+                        columns=[
+                            ObjectColumn(name="name", width=0.70),
+                            ObjectColumn(
+                                name="hits", editable=False, width=0.29
+                            ),
+                        ],
+                        selected="object.player",
+                        auto_add=True,
+                        row_factory=Player,
+                        configurable=False,
+                        sortable=False,
+                    ),
+                ),
+                "_",
+                HGroup(
+                    Item(
+                        "got_hit",
+                        show_label=False,
+                        enabled_when="player is not None",
+                    )
+                ),
+                label="Team Players",
                 show_labels=False,
                 show_border=True,
-                ),
             ),
+        ),
         resizable=True,
-        )
+    )
 
     def _model_changed(self, model):
         """ Handles the 'league' model being initialized.
@@ -202,28 +221,44 @@ class LeagueModelView(ModelView):
         else:
             self.player = None
 
+
 # Function to add two numbers (used with 'reduce'):
 add = lambda a, b: a + b
 
-#--[Example*]------------------------------------------------------------------
+# --[Example*]------------------------------------------------------------------
 
 # Define some sample teams and players:
-blue_birds = Team(name='Blue Birds', players=[
-    Player(name='Mike Scott', hits=25),
-    Player(name='Willy Shofield', hits=37),
-    Player(name='Tony Barucci', hits=19)])
+blue_birds = Team(
+    name="Blue Birds",
+    players=[
+        Player(name="Mike Scott", hits=25),
+        Player(name="Willy Shofield", hits=37),
+        Player(name="Tony Barucci", hits=19),
+    ],
+)
 
-chicken_hawks = Team(name='Chicken Hawks', players=[
-    Player(name='Jimmy Domore', hits=34),
-    Player(name='Bill Janks', hits=16),
-    Player(name='Tim Saunders', hits=27)])
+chicken_hawks = Team(
+    name="Chicken Hawks",
+    players=[
+        Player(name="Jimmy Domore", hits=34),
+        Player(name="Bill Janks", hits=16),
+        Player(name="Tim Saunders", hits=27),
+    ],
+)
 
-eagles = Team(name='Eagles', players=[
-    Player(name='Joe Peppers', hits=33),
-    Player(name='Sam Alone', hits=12),
-    Player(name='Roger Clemson', hits=23)])
+eagles = Team(
+    name="Eagles",
+    players=[
+        Player(name="Joe Peppers", hits=33),
+        Player(name="Sam Alone", hits=12),
+        Player(name="Roger Clemson", hits=23),
+    ],
+)
 
 # Create a league and its corresponding model view:
 demo = LeagueModelView(
-    League(name='National Baseball Conference',
-           teams=[blue_birds, chicken_hawks, eagles]))
+    League(
+        name="National Baseball Conference",
+        teams=[blue_birds, chicken_hawks, eagles],
+    )
+)
