@@ -1,7 +1,7 @@
 #  Copyright (c) 2007, Enthought, Inc.
 #  License: BSD Style.
 
-#--(New Trait Definition Style)------------------------------------------------
+# --(New Trait Definition Style)------------------------------------------------
 """
 New Trait Definition Style
 ==========================
@@ -91,19 +91,19 @@ This provides the exact same functionality as the previous definition of
   creating a new trait type a little more understandable to a wider group of
   developers.
 """
-#--<Imports>-------------------------------------------------------------------
-
+# --<Imports>-------------------------------------------------------------------
+from __future__ import print_function
 from traits.api import *
 
 
-#--[OddInt Definition]---------------------------------------------------------
+# --[OddInt Definition]---------------------------------------------------------
 class OddInt(Int):
 
     # Define the default value:
     default_value = 1
 
     # Describe the trait type:
-    info_text = 'an odd integer'
+    info_text = "an odd integer"
 
     def validate(self, object, name, value):
         value = super(OddInt, self).validate(object, name, value)
@@ -113,27 +113,28 @@ class OddInt(Int):
         self.error(object, name, value)
 
 
-#--[Test Class]----------------------------------------------------------------
+# --[Test Class]----------------------------------------------------------------
 class Test(HasTraits):
 
     any_int = Int
     odd_int = OddInt
 
-#--[Example*]------------------------------------------------------------------
+
+# --[Example*]------------------------------------------------------------------
 
 # Create a test object:
 t = Test()
 
 # Set both traits to an odd integer value:
 t.any_int = 1
-print "t.any_int:", t.any_int
+print("t.any_int:", t.any_int)
 
 t.odd_int = 1
-print "t.odd_int:", t.odd_int
+print("t.odd_int:", t.odd_int)
 
 # Now set them both to an even value (and see what happens):
 t.any_int = 2
-print "t.any_int:", t.any_int
+print("t.any_int:", t.any_int)
 
 t.odd_int = 2
-print "t.odd_int:", t.odd_int  # Should never get here!
+print("t.odd_int:", t.odd_int)  # Should never get here!
