@@ -1,4 +1,4 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Copyright (c) 2013, Enthought, Inc.
 # All rights reserved.
 #
@@ -9,16 +9,17 @@
 # Thanks for using Enthought open source!
 #
 # Author: Enthought, Inc.
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 """ Manages all registered adaptations. """
 
 
 from heapq import heappop, heappush
 import inspect
 import itertools
-import sys
 import functools
 
+import six
+
 from traits.adaptation.adaptation_error import AdaptationError
 from traits.has_traits import HasTraits
 from traits.trait_types import Dict, List, Str
@@ -92,10 +93,7 @@ class AdaptationManager(HasTraits):
           True if the object provides the protocol, otherwise False.
 
         """
-
-        # We do the 'is' check first as a performance improvement to save us
-        # a call to 'issubclass'.
-        return type_ is protocol or issubclass(type_, protocol)
+        return issubclass(type_, protocol)
 
     #### 'AdaptationManager' protocol ##########################################
 
@@ -136,7 +134,8 @@ class AdaptationManager(HasTraits):
         if result is None:
             if default is AdaptationError:
                 raise AdaptationError(
-                    'Could not adapt %r to %r' % (adaptee, to_protocol))
+                    "Could not adapt %r to %r" % (adaptee, to_protocol)
+                )
             else:
                 result = default
 
@@ -164,9 +163,9 @@ class AdaptationManager(HasTraits):
 
         self.register_offer(
             AdaptationOffer(
-                factory       = factory,
-                from_protocol = from_protocol,
-                to_protocol   = to_protocol
+                factory=factory,
+                from_protocol=from_protocol,
+                to_protocol=to_protocol,
             )
         )
 
@@ -175,7 +174,9 @@ class AdaptationManager(HasTraits):
     def register_provides(self, provider_protocol, protocol):
         """ Register that a protocol provides another. """
 
-        self.register_factory(no_adapter_necessary, provider_protocol, protocol)
+        self.register_factory(
+            no_adapter_necessary, provider_protocol, protocol
+        )
 
         return
 
@@ -264,12 +265,15 @@ class AdaptationManager(HasTraits):
             edges = self._get_applicable_offers(current_protocol, path)
 
             # Sort by weight first, then by from_protocol type.
-            if sys.version_info[0] < 3:
+            if six.PY2:
                 edges.sort(cmp=_by_weight_then_from_protocol_specificity)
             else:
                 # functools.cmp_to_key is available from 2.7 and 3.2
-                edges.sort(key=functools.cmp_to_key(_by_weight_then_from_protocol_specificity))
-
+                edges.sort(
+                    key=functools.cmp_to_key(
+                        _by_weight_then_from_protocol_specificity
+                    )
+                )
 
             # At this point, the first edges are the shortest ones. Within
             # edges with the same distance, interfaces which are subclasses
@@ -298,12 +302,13 @@ class AdaptationManager(HasTraits):
                 else:
                     # Push the new path on the priority queue.
                     adapter_weight, mro_weight, _ = weight
-                    new_weight = (adapter_weight + 1,
-                                  mro_weight + mro_distance,
-                                  next(counter))
+                    new_weight = (
+                        adapter_weight + 1,
+                        mro_weight + mro_distance,
+                        next(counter),
+                    )
                     heappush(
-                        offer_queue,
-                        (new_weight, new_path, offer.to_protocol)
+                        offer_queue, (new_weight, new_path, offer.to_protocol)
                     )
 
         return None
@@ -338,6 +343,7 @@ class AdaptationManager(HasTraits):
 
         return edges
 
+
 def _by_weight_then_from_protocol_specificity(edge_1, edge_2):
     """ Comparison function for graph edges.
 
@@ -409,6 +415,7 @@ def get_global_adaptation_manager():
 # If you add a public method to the adaptation manager protocol then don't
 # forget to add a convenience function here!
 
+
 def adapt(adaptee, to_protocol, default=AdaptationError):
     """ Attempt to adapt an object to a given protocol. """
     manager = get_global_adaptation_manager()
@@ -442,5 +449,3 @@ def supports_protocol(obj, protocol):
 def provides_protocol(type_, protocol):
     """ Does the given type provide (i.e implement) a given protocol? """
     return AdaptationManager.provides_protocol(type_, protocol)
-
-#### EOF ######################################################################
