@@ -1,4 +1,4 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Copyright (c) 2005-2013, Enthought, Inc.
 # All rights reserved.
 #
@@ -7,7 +7,7 @@
 # under the conditions described in the aforementioned license.  The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
 # Thanks for using Enthought open source!
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 """ Trait assert mixin class to simplify test implementation for Trait
 Classes.
 
@@ -18,16 +18,23 @@ import threading
 import sys
 import warnings
 
-from traits.api import (Any, Event, HasStrictTraits, Instance, Int, List,
-        Property, Str)
-from traits.util.async_trait_wait import wait_for_condition
+# Support for 'from traits.testing.unittest_tools import unittest',
+# which was used to make unittest2 available under the name unittest
+# on Python 2.6. We keep the import for now, for backwards compatibility.
+import unittest  # noqa: F401
 
-# Compatibility layer for Python 2.6: try loading unittest2
+from traits.api import (
+    Any,
+    Event,
+    HasStrictTraits,
+    Instance,
+    Int,
+    List,
+    Str,
+    Property,
+)
+from traits.util.async_trait_wait import wait_for_condition
 from traits import _py2to3
-if sys.version_info[:2] == (2, 6):
-    import unittest2 as unittest
-else:
-    import unittest
 
 
 class _AssertTraitChangesContext(object):
@@ -36,7 +43,7 @@ class _AssertTraitChangesContext(object):
     Attributes
     ----------
     obj : HasTraits
-        The HasTraits class instance who's class trait will change.
+        The HasTraits class instance whose class trait will change.
 
     xname : str
         The extended trait name of trait changes to listen to.
@@ -64,7 +71,7 @@ class _AssertTraitChangesContext(object):
         Parameters
         ----------
         obj : HasTraits
-            The HasTraits class instance who's class trait will change.
+            The HasTraits class instance whose class trait will change.
 
         xname : str
             The extended trait name of trait changes to listen to.
@@ -111,11 +118,11 @@ class _AssertTraitChangesContext(object):
 
         self.obj.on_trait_change(self._listener, self.xname, remove=True)
         if self.count is not None and len(self.events) != self.count:
-            msg = 'Change event for {0} was fired {1} times instead of {2}'
+            msg = "Change event for {0} was fired {1} times instead of {2}"
             items = self.xname, len(self.events), self.count
             raise self.failureException(msg.format(*items))
         elif self.count is None and not self.events:
-            msg = 'A change event was not fired for: {0}'.format(self.xname)
+            msg = "A change event was not fired for: {0}".format(self.xname)
             raise self.failureException(msg)
         return False
 
@@ -137,11 +144,12 @@ def reverse_assertion(context, msg):
 class _TraitsChangeCollector(HasStrictTraits):
     """ Class allowing thread-safe recording of events.
     """
+
     # The object we're listening to.
     obj = Any
 
-    # The (possibly extended) trait name.
-    trait = Str
+    # The (possibly extended) trait name(s).
+    trait_name = Str
 
     # Read-only event count.
     event_count = Property(Int)
@@ -156,17 +164,22 @@ class _TraitsChangeCollector(HasStrictTraits):
     # simultaneously.
     _lock = Instance(threading.Lock, ())
 
+    def __init__(self, **traits):
+        if "trait" in traits:
+            value = traits.pop("trait")
+            message = (
+                "The `trait` keyword is deprecated." " please use `trait_name`"
+            )
+            warnings.warn(message, DeprecationWarning, stacklevel=2)
+            traits["trait_name"] = value
+        super(_TraitsChangeCollector, self).__init__(**traits)
+
     def start_collecting(self):
-        self.obj.on_trait_change(
-            self._event_handler,
-            self.trait,
-        )
+        self.obj.on_trait_change(self._event_handler, self.trait_name)
 
     def stop_collecting(self):
         self.obj.on_trait_change(
-            self._event_handler,
-            self.trait,
-            remove=True,
+            self._event_handler, self.trait_name, remove=True
         )
 
     def _event_handler(self, new):
@@ -190,8 +203,9 @@ class UnittestTools(object):
 
     """
 
-    def assertTraitChanges(self, obj, trait, count=None, callableObj=None,
-                           *args, **kwargs):
+    def assertTraitChanges(
+        self, obj, trait, count=None, callableObj=None, *args, **kwargs
+    ):
         """ Assert an object trait changes a given number of times.
 
         Assert that the class trait changes exactly `count` times during
@@ -221,7 +235,7 @@ class UnittestTools(object):
 
             my_class = MyClass()
 
-            with self.assertTraitChangesExactly(my_class, 'number', count=1):
+            with self.assertTraitChanges(my_class, 'number', count=1):
                 my_class.number = 3.0
 
         Parameters
@@ -272,8 +286,9 @@ class UnittestTools(object):
         with context:
             callableObj(*args, **kwargs)
 
-    def assertTraitDoesNotChange(self, obj, trait, callableObj=None,
-                                 *args, **kwargs):
+    def assertTraitDoesNotChange(
+        self, obj, trait, callableObj=None, *args, **kwargs
+    ):
         """ Assert an object trait does not change.
 
         Assert that the class trait does not change during
@@ -309,7 +324,7 @@ class UnittestTools(object):
 
 
         """
-        msg = 'A change event was fired for: {0}'.format(trait)
+        msg = "A change event was fired for: {0}".format(trait)
         context = _AssertTraitChangesContext(obj, trait, None, self)
         if callableObj is None:
             return reverse_assertion(context, msg)
@@ -317,8 +332,9 @@ class UnittestTools(object):
             callableObj(*args, **kwargs)
         return
 
-    def assertMultiTraitChanges(self, objects, traits_modified,
-            traits_not_modified):
+    def assertMultiTraitChanges(
+        self, objects, traits_modified, traits_not_modified
+    ):
         """ Assert that traits on multiple objects do or do not change.
 
         This combines some of the functionality of `assertTraitChanges` and
@@ -377,7 +393,7 @@ class UnittestTools(object):
             of changes. None can be used to indicate no timeout.
 
         """
-        collector = _TraitsChangeCollector(obj=obj, trait=trait)
+        collector = _TraitsChangeCollector(obj=obj, trait_name=trait)
 
         # Pass control to body of the with statement.
         collector.start_collecting()
@@ -389,20 +405,16 @@ class UnittestTools(object):
                 wait_for_condition(
                     condition=lambda obj: obj.event_count >= count,
                     obj=collector,
-                    trait='event_count_updated',
+                    trait="event_count_updated",
                     timeout=timeout,
                 )
             except RuntimeError:
                 actual_event_count = collector.event_count
-                msg = ("Expected {0} event on {1} to be fired at least {2} "
-                       "times, but the event was only fired {3} times "
-                       "before timeout ({4} seconds).").format(
-                    trait,
-                    obj,
-                    count,
-                    actual_event_count,
-                    timeout,
-                )
+                msg = (
+                    "Expected {0} event on {1} to be fired at least {2} "
+                    "times, but the event was only fired {3} times "
+                    "before timeout ({4} seconds)."
+                ).format(trait, obj, count, actual_event_count, timeout)
                 self.fail(msg)
 
         finally:
@@ -414,7 +426,7 @@ class UnittestTools(object):
         Parameters
         ----------
         obj : HasTraits
-            The HasTraits class instance who's traits will change.
+            The HasTraits class instance whose traits will change.
 
         trait : str
             The extended trait name of trait changes to listen to.
@@ -431,10 +443,7 @@ class UnittestTools(object):
         """
         try:
             wait_for_condition(
-                condition=condition,
-                obj=obj,
-                trait=trait,
-                timeout=timeout,
+                condition=condition, obj=obj, trait=trait, timeout=timeout
             )
         except RuntimeError:
             # Helpful to know whether we timed out because the
@@ -443,7 +452,8 @@ class UnittestTools(object):
             condition_at_timeout = condition(obj)
             self.fail(
                 "Timed out waiting for condition. "
-                "At timeout, condition was {0}.".format(condition_at_timeout))
+                "At timeout, condition was {0}.".format(condition_at_timeout)
+            )
 
     @contextlib.contextmanager
     def _catch_warnings(self):
@@ -453,12 +463,12 @@ class UnittestTools(object):
         #
         # Note that this hack is unnecessary in Python 3.4 and later; see
         # http://bugs.python.org/issue4180 for the background.
-        registry = sys._getframe(4).f_globals.get('__warningregistry__')
+        registry = sys._getframe(4).f_globals.get("__warningregistry__")
         if registry:
             registry.clear()
 
         with warnings.catch_warnings(record=True) as w:
-            warnings.simplefilter('always', DeprecationWarning)
+            warnings.simplefilter("always", DeprecationWarning)
             yield w
 
     @contextlib.contextmanager
@@ -470,8 +480,11 @@ class UnittestTools(object):
         """
         with self._catch_warnings() as w:
             yield w
-        self.assertGreater(len(w), 0, msg="Expected a DeprecationWarning, "
-                           "but none was issued")
+        self.assertGreater(
+            len(w),
+            0,
+            msg="Expected a DeprecationWarning, " "but none was issued",
+        )
 
     @contextlib.contextmanager
     def assertNotDeprecated(self):
@@ -482,5 +495,9 @@ class UnittestTools(object):
         """
         with self._catch_warnings() as w:
             yield w
-        self.assertEqual(len(w), 0, msg="Expected no DeprecationWarning, "
-                         "but at least one was issued")
+        self.assertEqual(
+            len(w),
+            0,
+            msg="Expected no DeprecationWarning, "
+            "but at least one was issued",
+        )
