@@ -12,7 +12,7 @@
 # Description: Perform timing tests on various trait styles to determine the
 #              amount of overhead that traits add.
 
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 from time import time
 from ..api import Any, DelegatesTo, HasTraits, Int, Range
@@ -33,7 +33,6 @@ def measure(func):
 
 #  'Old style' Python attribute get/set:
 class old_style_value:
-
     def measure(self, reference_get=1.0, reference_set=1.0):
         global t0
         self.init()
@@ -67,7 +66,6 @@ class old_style_value:
 
 #  'New style' Python attribute get/set:
 class new_style_value(object):
-
     def measure(self):
         global t0
         self.init()
@@ -101,7 +99,6 @@ class new_style_value(object):
 
 #  Python 'property' get/set:
 class property_value(new_style_value):
-
     def get_value(self):
         return self._value
 
@@ -113,7 +110,6 @@ class property_value(new_style_value):
 
 #  Python 'global' get/set:
 class global_value(new_style_value):
-
     def init(self):
         global gvalue
         gvalue = -1
@@ -149,16 +145,14 @@ class range_value(any_value):
 
 #  Executes method when float trait is changed:
 class change_value(int_value):
-
     def _value_changed(self, old, new):
         pass
 
 
 #  Notifies handler when float trait is changed:
 class monitor_value(int_value):
-
     def init(self):
-        self.on_trait_change(self.on_value_change, 'value')
+        self.on_trait_change(self.on_value_change, "value")
 
     def on_value_change(self, object, trait_name, old, new):
         pass
@@ -167,7 +161,7 @@ class monitor_value(int_value):
 #  Float trait is delegated to another object:
 class delegate_value(HasTraits, new_style_value):
 
-    value = DelegatesTo('delegate')
+    value = DelegatesTo("delegate")
     delegate = Any
 
     def init(self):
@@ -176,7 +170,6 @@ class delegate_value(HasTraits, new_style_value):
 
 #  Float trait is delegated through one object to another object:
 class delegate_2_value(delegate_value):
-
     def init(self):
         delegate = delegate_value()
         delegate.init()
@@ -185,7 +178,6 @@ class delegate_2_value(delegate_value):
 
 #  Float trait is delegated through two objects to another object:
 class delegate_3_value(delegate_value):
-
     def init(self):
         delegate = delegate_2_value()
         delegate.init()
@@ -203,9 +195,9 @@ def report(name, get_time, set_time, ref_get_time, ref_set_time):
     """
 
     template = (
-        '{name:^30}: Get {get_time:02.3f} us (x {get_speed_up:02.3f}), '
-        'Set {set_time:02.3f} us (x {set_speed_up:02.3f})'
-        )
+        "{name:^30}: Get {get_time:02.3f} us (x {get_speed_up:02.3f}), "
+        "Set {set_time:02.3f} us (x {set_speed_up:02.3f})"
+    )
 
     report = template.format(
         name=name,
@@ -213,7 +205,7 @@ def report(name, get_time, set_time, ref_get_time, ref_set_time):
         get_speed_up=ref_get_time / get_time,
         set_time=set_time,
         set_speed_up=ref_set_time / set_time,
-        )
+    )
 
     return report
 
@@ -221,9 +213,9 @@ def report(name, get_time, set_time, ref_get_time, ref_set_time):
 def run_benchmark(klass, ref_get_time, ref_set_time):
     benchmark_name = klass.__name__
     get_time, set_time = klass().measure()
-    print report(benchmark_name,
-                 get_time, set_time,
-                 ref_get_time, ref_set_time)
+    print(
+        report(benchmark_name, get_time, set_time, ref_get_time, ref_set_time)
+    )
 
 
 def main():
@@ -241,11 +233,12 @@ def main():
         monitor_value,
         delegate_value,
         delegate_2_value,
-        delegate_3_value
+        delegate_3_value,
     ]
 
     for benchmark in benchmarks:
         run_benchmark(benchmark, ref_get_time, ref_set_time)
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     main()
