@@ -11,12 +11,20 @@
 from __future__ import absolute_import
 
 # Standard library imports.
-from traits.testing.unittest_tools import unittest
+import unittest
+import warnings
 
 # Enthought library imports.
 from traits.adaptation.api import reset_global_adaptation_manager
-from traits.api import Adapter, HasTraits, Instance, Int, Interface, \
-    provides, register_factory
+from traits.api import (
+    Adapter,
+    HasTraits,
+    Instance,
+    Int,
+    Interface,
+    provides,
+    register_factory,
+)
 
 # Local imports.
 from traits.interface_checker import InterfaceError, check_implements
@@ -24,6 +32,7 @@ from traits.interface_checker import InterfaceError, check_implements
 # Make sure implicit interface checking is turned off, so that we can make the
 # checks explicitly:
 from traits import has_traits
+
 has_traits.CHECK_INTERFACES = 0
 
 
@@ -54,7 +63,6 @@ class InterfaceCheckerTestCase(unittest.TestCase):
         # A class that *does* implement the interface.
         @provides(IFoo)
         class Foo(object):
-
             def foo(self):
                 pass
 
@@ -173,7 +181,6 @@ class InterfaceCheckerTestCase(unittest.TestCase):
         # A class that does *not* implement the interface.
         @provides(IFoo, IBar, IBaz)
         class Foo(HasTraits):
-
             def foo(self):
                 pass
 
@@ -233,7 +240,6 @@ class InterfaceCheckerTestCase(unittest.TestCase):
         # A class that does *not* implement the interface.
         @provides(IFoo, IBar, IBaz)
         class Foo(HasTraits):
-
             def foo(self):
                 pass
 
@@ -289,7 +295,6 @@ class InterfaceCheckerTestCase(unittest.TestCase):
         # A class that does *not* implement the interface.
         @provides(IBaz)
         class Foo(HasTraits):
-
             def foo(self):
                 pass
 
@@ -345,7 +350,6 @@ class InterfaceCheckerTestCase(unittest.TestCase):
         # A class that does *not* implement the interface.
         @provides(IBaz)
         class Foo(HasTraits):
-
             def foo(self):
                 pass
 
@@ -360,19 +364,15 @@ class InterfaceCheckerTestCase(unittest.TestCase):
         """ Subclasses with incorrect method signatures """
 
         class IFoo(Interface):
-
             def foo(self, argument):
                 pass
 
         @provides(IFoo)
         class Foo(HasTraits):
-
             def foo(self, argument):
                 pass
 
-
         class Bar(Foo):
-
             def foo(self):
                 pass
 
@@ -393,7 +393,7 @@ class InterfaceCheckerTestCase(unittest.TestCase):
         class Bar(HasTraits):
             foo = Instance(IFoo)
 
-        b = Bar(foo=Foo())
+        Bar(foo=Foo())
 
         return
 
@@ -408,9 +408,18 @@ class InterfaceCheckerTestCase(unittest.TestCase):
             pass
 
         f = Foo()
-        self.assertEqual(f, IFoo(f))
 
-        return
+        # Adaptation via direct instantiation of interfaces is deprecated, so
+        # catch the warning to keep the test run output clean.
+        with warnings.catch_warnings(record=True) as warn_msgs:
+            warnings.simplefilter("always", DeprecationWarning)
+            self.assertEqual(f, IFoo(f))
+
+        self.assertEqual(len(warn_msgs), 1)
+        warn_msg = warn_msgs[0]
+        self.assertIn(
+            'use "adapt(adaptee, protocol)" instead', str(warn_msg.message))
+        self.assertIn("test_interface_checker", warn_msg.filename)
 
     def test_adaptation(self):
         """ adaptation """
@@ -429,14 +438,17 @@ class InterfaceCheckerTestCase(unittest.TestCase):
 
         f = Foo()
 
-        # Make sure adaptation works.
-        i_foo = IFoo(f)
+        # Make sure adaptation works. Adaptation via direct instantiation of
+        # Interface classes is deprecated, so suppress the warning.
+        with warnings.catch_warnings(record=True) as warn_msgs:
+            warnings.simplefilter("always", DeprecationWarning)
+            i_foo = IFoo(f)
 
         self.assertNotEqual(None, i_foo)
         self.assertEqual(FooToIFooAdapter, type(i_foo))
-        return
 
-
-# Entry point for stand-alone testing.
-if __name__ == '__main__':
-    unittest.main()
+        self.assertEqual(len(warn_msgs), 1)
+        warn_msg = warn_msgs[0]
+        self.assertIn(
+            'use "adapt(adaptee, protocol)" instead', str(warn_msg.message))
+        self.assertIn("test_interface_checker", warn_msg.filename)
