@@ -20,15 +20,15 @@
 from __future__ import absolute_import
 
 import contextlib
-import cStringIO
 import sys
 import threading
 import time
+import unittest
 
-from traits.testing.unittest_tools import unittest
+import six
 
-from ..api import HasTraits, Str, Int, Float, Any, Event
-from ..api import push_exception_handler, pop_exception_handler
+from traits.api import HasTraits, Str, Int, Float, Any, Event
+from traits.api import push_exception_handler, pop_exception_handler
 
 
 @contextlib.contextmanager
@@ -37,7 +37,7 @@ def captured_stderr():
     Return a context manager that directs all stderr output to a string.
 
     """
-    new_stderr = cStringIO.StringIO()
+    new_stderr = six.StringIO()
     original_stderr = sys.stderr
     sys.stderr = new_stderr
     try:
@@ -51,6 +51,7 @@ class GenerateEvents(HasTraits):
     age = Int
     weight = Float
 
+
 events = {}  # dict of events
 
 
@@ -77,12 +78,13 @@ class ListenEvents(HasTraits):
 
 class GenerateFailingEvents(HasTraits):
     name = Str
+
     def _name_changed(self):
         raise RuntimeError
 
-class Test_Listeners(unittest.TestCase):
 
-    def test(self):
+class TestListeners(unittest.TestCase):
+    def test_listeners(self):
         global events
 
         # FIXME: comparing floats
@@ -90,43 +92,52 @@ class Test_Listeners(unittest.TestCase):
         le = ListenEvents()
 
         # Starting test: No Listeners
-        ge.trait_set(name='Joe', age=22, weight=152.0)
+        ge.trait_set(name="Joe", age=22, weight=152.0)
 
         # Adding default listener
         ge.add_trait_listener(le)
         events = {}
-        ge.trait_set(name='Mike', age=34, weight=178.0)
-        self.assertEqual(events, {
-            '_age_changed': ('age', 22, 34),
-            '_weight_changed': ('weight', 152.0, 178.0),
-            '_name_changed': ('name', 'Joe', 'Mike'),
-            })
+        ge.trait_set(name="Mike", age=34, weight=178.0)
+        self.assertEqual(
+            events,
+            {
+                "_age_changed": ("age", 22, 34),
+                "_weight_changed": ("weight", 152.0, 178.0),
+                "_name_changed": ("name", "Joe", "Mike"),
+            },
+        )
 
         # Adding alternate listener
-        ge.add_trait_listener(le, 'alt')
+        ge.add_trait_listener(le, "alt")
         events = {}
-        ge.trait_set(name='Gertrude', age=39, weight=108.0)
-        self.assertEqual(events, {
-            '_age_changed': ('age', 34, 39),
-            '_name_changed': ('name', 'Mike', 'Gertrude'),
-            '_weight_changed': ('weight', 178.0, 108.0),
-            'alt_name_changed': ('name', 'Mike', 'Gertrude'),
-            'alt_weight_changed': ('weight', 178.0, 108.0),
-            })
+        ge.trait_set(name="Gertrude", age=39, weight=108.0)
+        self.assertEqual(
+            events,
+            {
+                "_age_changed": ("age", 34, 39),
+                "_name_changed": ("name", "Mike", "Gertrude"),
+                "_weight_changed": ("weight", 178.0, 108.0),
+                "alt_name_changed": ("name", "Mike", "Gertrude"),
+                "alt_weight_changed": ("weight", 178.0, 108.0),
+            },
+        )
 
         # Removing default listener
         ge.remove_trait_listener(le)
         events = {}
-        ge.trait_set(name='Sally', age=46, weight=118.0)
-        self.assertEqual(events, {
-            'alt_name_changed': ('name', 'Gertrude', 'Sally'),
-            'alt_weight_changed': ('weight', 108.0, 118.0),
-            })
+        ge.trait_set(name="Sally", age=46, weight=118.0)
+        self.assertEqual(
+            events,
+            {
+                "alt_name_changed": ("name", "Gertrude", "Sally"),
+                "alt_weight_changed": ("weight", 108.0, 118.0),
+            },
+        )
 
         # Removing alternate listener
-        ge.remove_trait_listener(le, 'alt')
+        ge.remove_trait_listener(le, "alt")
         events = {}
-        ge.trait_set(name='Ralph', age=29, weight=198.0)
+        ge.trait_set(name="Ralph", age=29, weight=198.0)
         self.assertEqual(events, {})
 
     def test_trait_exception_handler_can_access_exception(self):
@@ -135,19 +146,20 @@ class Test_Listeners(unittest.TestCase):
         import traceback
 
         from traits import trait_notifiers
-        def _handle_exception(obj,name,old,new):
+
+        def _handle_exception(obj, name, old, new):
             self.assertIsNotNone(sys.exc_info()[0])
+
         ge = GenerateFailingEvents()
         try:
             trait_notifiers.push_exception_handler(
-                _handle_exception,
-                reraise_exceptions=False,
-                main=True
+                _handle_exception, reraise_exceptions=False, main=True
             )
-            ge.trait_set(name='John Cleese')
+            ge.trait_set(name="John Cleese")
         finally:
             trait_notifiers.pop_exception_handler()
 
+
 class A(HasTraits):
     exception = Any
 
@@ -168,10 +180,8 @@ def foo_writer(a, stop_event):
 class TestRaceCondition(unittest.TestCase):
     def setUp(self):
         push_exception_handler(
-            handler=lambda *args: None,
-            reraise_exceptions=True,
-            main=True,
-            )
+            handler=lambda *args: None, reraise_exceptions=True, main=True
+        )
 
     def tearDown(self):
         pop_exception_handler()
@@ -184,10 +194,10 @@ class TestRaceCondition(unittest.TestCase):
         t = threading.Thread(target=foo_writer, args=(a, stop_event))
         t.start()
 
-        for _ in xrange(100):
-            a.on_trait_change(a.foo_changed_handler, 'foo')
+        for _ in range(100):
+            a.on_trait_change(a.foo_changed_handler, "foo")
             time.sleep(0.0001)  # encourage thread-switch
-            a.on_trait_change(a.foo_changed_handler, 'foo', remove=True)
+            a.on_trait_change(a.foo_changed_handler, "foo", remove=True)
 
         stop_event.set()
         t.join()
@@ -210,13 +220,14 @@ class TestRaceCondition(unittest.TestCase):
 
         def main_thread(event_source, start_event):
             listener = SlowListener()
-            event_source.on_trait_change(listener.handle_age_change, 'age')
+            event_source.on_trait_change(listener.handle_age_change, "age")
             start_event.set()
             # Allow time to make sure that we're in the middle of handling an
             # event.
             time.sleep(0.5)
             event_source.on_trait_change(
-                listener.handle_age_change, 'age', remove=True)
+                listener.handle_age_change, "age", remove=True
+            )
 
         # Previously, a ValueError would be raised on the worker thread
         # during (normal refcount-based) garbage collection.  That
@@ -226,16 +237,10 @@ class TestRaceCondition(unittest.TestCase):
             start_event = threading.Event()
             event_source = GenerateEvents(age=10)
             t = threading.Thread(
-                target=worker_thread,
-                args=(event_source, start_event),
-                )
+                target=worker_thread, args=(event_source, start_event)
+            )
             t.start()
             main_thread(event_source, start_event)
             t.join()
 
-        self.assertNotIn('Exception', s.getvalue())
-
-
-# Run the unit tests (if invoked from the command line):
-if __name__ == '__main__':
-    unittest.main()
+        self.assertNotIn("Exception", s.getvalue())
