@@ -8,11 +8,11 @@ Most of the functionality of the class is thus already covered by the
 notification really occurs on a separate thread.
 
 """
-import thread
+import threading
 import time
+import unittest
 
 from traits.api import Float, HasTraits
-from traits.testing.unittest_tools import unittest
 
 
 class Foo(HasTraits):
@@ -26,23 +26,19 @@ class TestNewNotifiers(unittest.TestCase):
         notifications = []
 
         def on_foo_notifications(obj, name, old, new):
-            thread_id = thread.get_ident()
+            thread_id = threading.current_thread().ident
             event = (thread_id, obj, name, old, new)
             notifications.append(event)
 
         obj = Foo()
-        obj.on_trait_change(on_foo_notifications, 'foo', dispatch='new')
+        obj.on_trait_change(on_foo_notifications, "foo", dispatch="new")
 
         obj.foo = 3
         # Wait for a while to make sure the notification has finished.
         time.sleep(0.1)
 
         self.assertEqual(len(notifications), 1)
-        self.assertEqual(notifications[0][1:], (obj, 'foo', 0, 3))
+        self.assertEqual(notifications[0][1:], (obj, "foo", 0, 3))
 
-        this_thread_id = thread.get_ident()
+        this_thread_id = threading.current_thread().ident
         self.assertNotEqual(this_thread_id, notifications[0][0])
-
-
-if __name__ == '__main__':
-    unittest.main()
