@@ -1,4 +1,4 @@
-from traits.testing.unittest_tools import unittest
+import unittest
 
 from traits.api import Any, HasStrictTraits, Str
 
@@ -12,22 +12,22 @@ class TestSpecialEvent(unittest.TestCase):
         self.foo = Foo(test=self)
 
     def test_events(self):
-        self.foo.val = 'CHANGE'
+        self.foo.val = "CHANGE"
 
-        values = ['CHANGE']
+        values = ["CHANGE"]
         self.assertEqual(self.change_events, values)
 
     def test_instance_events(self):
         foo = self.foo
-        foo.add_trait('val2', Str(event='the_trait'))
-        foo.val2 = 'CHANGE2'
+        foo.add_trait("val2", Str(event="the_trait"))
+        foo.val2 = "CHANGE2"
 
-        values = ['CHANGE2']
+        values = ["CHANGE2"]
         self.assertEqual(self.change_events, values)
 
 
 class Foo(HasStrictTraits):
-    val = Str(event='the_trait')
+    val = Str(event="the_trait")
     test = Any(None)
 
     def _the_trait_changed(self, new):
