@@ -1,4 +1,4 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2015, Enthought, Inc.
 #  All rights reserved.
@@ -10,21 +10,15 @@
 #
 #  Thanks for using Enthought open source!
 #
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 """
 Tests for the String trait type.
 
 """
-try:
-    import numpy
-except ImportError:
-    numpy_available = False
-else:
-    numpy_available = True
+import unittest
 
-from traits.testing.unittest_tools import unittest
-
-from ..api import HasTraits, String
+from traits.api import HasTraits, String
+from traits.testing.optional_dependencies import numpy, requires_numpy
 
 
 class A(HasTraits):
@@ -32,7 +26,7 @@ class A(HasTraits):
 
 
 class TestString(unittest.TestCase):
-    @unittest.skipUnless(numpy_available, "numpy not available")
+    @requires_numpy
     def test_accepts_numpy_string(self):
         numpy_string = numpy.str_("this is a numpy string!")
         a = A()
