@@ -1,4 +1,4 @@
-#-------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #
 #  Copyright (c) 2007, Enthought, Inc.
 #  All rights reserved.
@@ -10,10 +10,7 @@
 #
 #  Thanks for using Enthought open source!
 #
-#-------------------------------------------------------------------------------
-
-
-
+# ------------------------------------------------------------------------------
 """ Test whether HasTraits objects with cycles can be garbage collected.
 """
 
@@ -21,10 +18,11 @@ from __future__ import absolute_import
 
 import gc
 import time
-from traits.testing.unittest_tools import unittest
+import unittest
 
 # Enthought library imports
-from ..api import HasTraits, Any, DelegatesTo, Instance, Int
+from traits.api import HasTraits, Any, DelegatesTo, Instance, Int
+
 
 class TestCase(unittest.TestCase):
     def _simple_cycle_helper(self, foo_class):
@@ -34,10 +32,10 @@ class TestCase(unittest.TestCase):
         # Create two Foo objects that refer to each other.
         first = foo_class()
         second = foo_class(child=first)
-        first.child=second
+        first.child = second
 
         # get their ids
-        foo_ids =  [id(first), id(second)]
+        foo_ids = [id(first), id(second)]
 
         # delete the items so that they can be garbage collected
         del first, second
@@ -55,8 +53,9 @@ class TestCase(unittest.TestCase):
     def test_simple_cycle_oldstyle_class(self):
         """ Can the garbage collector clean up a cycle with old style class?
         """
+
         class Foo:
-            def __init__(self,child=None):
+            def __init__(self, child=None):
                 self.child = child
 
         self._simple_cycle_helper(Foo)
@@ -64,8 +63,9 @@ class TestCase(unittest.TestCase):
     def test_simple_cycle_newstyle_class(self):
         """ Can the garbage collector clean up a cycle with new style class?
         """
+
         class Foo(object):
-            def __init__(self,child=None):
+            def __init__(self, child=None):
                 self.child = child
 
         self._simple_cycle_helper(Foo)
@@ -73,6 +73,7 @@ class TestCase(unittest.TestCase):
     def test_simple_cycle_hastraits(self):
         """ Can the garbage collector clean up a cycle with traits objects?
         """
+
         class Foo(HasTraits):
             child = Any
 
@@ -91,13 +92,14 @@ class TestCase(unittest.TestCase):
 
         foo = Foo()
 
-        # It seems like foo sometimes has not finished construction yet, so the
-        # frame found by referrers is not _exactly_ the same as Foo(). For more
-        # information, see the gc doc: http://docs.python.org/lib/module-gc.html
+        # It seems like foo sometimes has not finished construction yet, so
+        # the frame found by referrers is not _exactly_ the same as Foo(). For
+        # more information, see the gc doc: http://docs.python.org/lib/module-
+        # gc.html
         #
-        # The documentation says that this (get_referrers) should be used for no
-        # purpose other than debugging, so this is really not a good way to test
-        # the code.
+        # The documentation says that this (get_referrers) should be used for
+        # no purpose other than debugging, so this is really not a good way to
+        # test the code.
 
         time.sleep(0.1)
         referrers = gc.get_referrers(foo.__dict__)
@@ -108,18 +110,18 @@ class TestCase(unittest.TestCase):
     def test_delegates_to(self):
         """ Tests if an object that delegates to another is freed.
         """
+
         class Base(HasTraits):
             """ Object we are delegating to. """
 
             i = Int
 
-
         class Delegates(HasTraits):
             """ Object that delegates. """
 
             b = Instance(Base)
 
-            i = DelegatesTo('b')
+            i = DelegatesTo("b")
 
         # Make a pair of object
         b = Base()
@@ -131,8 +133,5 @@ class TestCase(unittest.TestCase):
             gc.collect(2)
 
         # See if we still have a Delegates
-        ds = [ obj for obj in gc.get_objects() if isinstance(obj, Delegates) ]
-        self.assert_(ds == [])
-
-if __name__ == '__main__':
-    unittest.main()
+        ds = [obj for obj in gc.get_objects() if isinstance(obj, Delegates)]
+        self.assertEqual(ds, [])
